@@ -39,6 +39,14 @@
 #ifndef	CCXX_AUDIO_H_
 #define	CCXX_AUDIO_H_
 
+#ifndef	CCXX_PACKING
+#if defined(__GNUC__)
+#define CCXX_PACKED
+#elif !defined(__hpux) && !defined(_AIX)
+#define CCXX_PACKED
+#endif 
+#endif
+
 #ifndef	W32
 #if defined(_WIN32) && defined(_MSC_VER)
 #define	W32
@@ -269,7 +277,7 @@ public:
 	typedef enum Error Error;
 
 
-#if defined(__GNUC__) || !defined(__hpux)
+#ifdef	CCXX_PACKED
 #pragma pack(1)
 #endif
 
@@ -325,7 +333,7 @@ public:
 		unsigned char genre;
 	}	mpeg_tagv1;
 
-#if defined(__GNUC__) || !defined(__hpux)
+#ifdef	CCXX_PACKED
 #pragma pack()
 #endif
 
